@@ -3,4 +3,5 @@
 from fromconfig.utils.types import is_mapping, is_pure_iterable
 from fromconfig.utils.libimport import from_import_string, to_import_string, try_import
 from fromconfig.utils.strenum import StrEnum
-from fromconfig.utils.nest import merge_dict, depth_map
+from fromconfig.utils.nest import flatten, expand, merge_dict, depth_map
+import fromconfig.utils.testing
